@@ -4,7 +4,7 @@ package Tk::GraphViz;
 use strict;
 use warnings;
 
-our $VERSION = '1.05';
+our $VERSION = '1.06';
 
 use Tk 800.020;
 use Tk::Font;
@@ -257,6 +257,7 @@ sub _startDot
     $pipe->reader ( @layout_cmd );
     while ( <$pipe> ) { push @{$self->{layout}}, $_; }
     $then->();
+    return 1;
   }
 
   my $fh  = Tk::IO->new(
@@ -865,7 +866,7 @@ sub _flatten {
 ######################################################################
 # Draw the node record shapes
 ######################################################################
-my $TEXT_MARGIN = 3; # arbitrarily chosen
+my $TEXT_MARGIN = 8; # arbitrarily chosen
 sub _createRecordNode
 {
   my ($self, $label, $shape_args, %attrs) = @_;
@@ -2103,7 +2104,7 @@ Lots of DOT language features not yet implemented
 
 =head1 ACKNOWLEDGEMENTS
 
-See http://www.graphviz.org/ for more info on the graphviz tools.
+See L<http://www.graphviz.org/> for more info on the graphviz tools.
 
 =head1 AUTHOR
 
